==> bam_reheader-0.2-py2.py3-none-any.whl: bam_reheader/main.py <==
#!/usr/bin/env python

import argparse
import logging
import os
import sys

import sqlalchemy

from cdis_pipe_utils import pipe_util
from cdis_pipe_utils import time_util
from cdis_pipe_utils import df_util

def get_bam_header(bam_path, step_dir, engine, logger):
    bam_name = os.path.basename(bam_path)
    header_name = bam_name + '.header'
    header_path = os.path.join(step_dir, header_name)
    cmd = ['samtools', 'view', '-H', bam_path, '>', header_path]
    shell_cmd = ' '.join(cmd)
    pipe_util.do_shell_command(shell_cmd, logger)
    return header_path

def reheader_bam(uuid, bam_path, engine, logger):
    step_dir = os.getcwd()
    bam_name = os.path.basename(bam_path)
    if pipe_util.already_step(step_dir, bam_name + '_reheader', logger):
        logger.info('already completed step `samtools reheader` of %s to %s' % (bam_path, bam_name))
    else:
        logger.info('running step `samtools reheader` of %s to %s' % (bam_path, bam_name))
        home_dir = os.path.expanduser('~')

        #orig header path
        orig_bam_header_path = get_bam_header(bam_path, step_dir, engine, logger)

        #new header path
        reheader_path = os.path.join(step_dir, bam_name + '.reheader')
        cmd = ['head', '-n1', orig_bam_header_path, '>', reheader_path]
        shell_cmd = ' '.join(cmd)
        pipe_util.do_shell_command(shell_cmd, logger)

        #remove @SQ from orig header
        cmd = ["sed", "-i", "'/^@SQ/d'", orig_bam_header_path]
        shell_cmd = ' '.join(cmd)
        pipe_util.do_shell_command(shell_cmd, logger)

        #new @SQ
        python_version = str(sys.version_info.major) + '.' + str(sys.version_info.minor)
        gdc_sq_header_path = os.path.join(home_dir, '.virtualenvs', 'p2_' + uuid, 'lib', 'python'+python_version, 'site-packages', 'bam-reheader' , 'GRCh38.d1.vd1.dict')

        #cat new@SQ to orig header
        cmd = ['cat',gdc_sq_header_path, '>>', reheader_path]
        shell_cmd = ' '.join(cmd)
        pipe_util.do_shell_command(shell_cmd, logger)

        #add program info to new header
        cmd = ['tail', '-n', '+2', orig_bam_header_path, '>>', reheader_path]
        shell_cmd = ' '.join(cmd)
        pipe_util.do_shell_command(shell_cmd, logger)

        #reheader BAM
        cmd = [ 'samtools', 'reheader', reheader_path, bam_path, '>', bam_name ]
        shell_cmd = ' '.join(cmd)
        output = pipe_util.do_shell_command(shell_cmd, logger)
        df = time_util.store_time(uuid, shell_cmd, output, logger)
        df['bam'] = bam_name
        unique_key_dict = {'uuid': uuid, 'bam': bam_name}
        table_name = 'time_mem_samtools_reheader'
        df_util.save_df_to_sqlalchemy(df, unique_key_dict, table_name, engine, logger)

        logger.info('completed running step `samtools reheader` of %s to %s' % (bam_path, bam_name))
        pipe_util.create_already_step(step_dir, bam_name + '_reheader', logger)
    return bam_name

def main():
    parser = argparse.ArgumentParser('reheader a BAM to include gdc @SQ info')

    # Logging flags.
    parser.add_argument('-d', '--debug',
        action = 'store_const',
        const = logging.DEBUG,
        dest = 'level',
        help = 'Enable debug logging.',
    )
    parser.set_defaults(level = logging.INFO)


    # Optional db flags
    parser.add_argument('--db_cred_s3url',
                        required = False
    )
    parser.add_argument('--s3cfg_path',
                        required = False
    )


    # Tool flags
    parser.add_argument('-b', '--bam_path',
                        required = True
    )
    parser.add_argument('-c', '--case_id',
                        required = True
    )

    args = parser.parse_args()
    bam_path = args.bam_path
    case_id = args.case_id
    if args.db_cred_s3url:
        db_cred_s3url = args.db_cred_s3url
        s3cfg_path = args.s3cfg_path
    else:
        db_cred_s3url = None

    bam_name = os.path.basename(bam_path)

    logger = pipe_util.setup_logging('readgroup_platform_insertion', args, bam_name)

    if db_cred_s3url is not None: #db server case
        conn_dict = pipe_util.get_connect_dict(db_cred_s3url, s3cfg_path, logger)
        engine = sqlalchemy.create_engine(sqlalchemy.engine.url.URL(**conn_dict))
    else: # local sqlite case
        sqlite_name =  bam_name + '_samtools_reheader.db'
        engine_path = 'sqlite:///' + sqlite_name
        engine = sqlalchemy.create_engine(engine_path, isolation_level='SERIALIZABLE')

    hostname = os.uname()[1]
    logger.info('hostname=%s' % hostname)

    bam_name = reheader_bam(case_id, bam_path, engine, logger)
    
    return


if __name__ == '__main__':
    main()

==> bam_reheader-0.7-py2.py3-none-any.whl: bam_reheader/main.py <==
#!/usr/bin/env python

import argparse
import logging
import os
import sys

import sqlalchemy

from cdis_pipe_utils import pipe_util
from cdis_pipe_utils import time_util
from cdis_pipe_utils import df_util

def get_bam_header(bam_path, step_dir, engine, logger):
    bam_name = os.path.basename(bam_path)
    header_name = bam_name + '.header'
    header_path = os.path.join(step_dir, header_name)
    cmd = ['samtools', 'view', '-H', bam_path, '>', header_path]
    shell_cmd = ' '.join(cmd)
    pipe_util.do_shell_command(shell_cmd, logger)
    return header_path

def reheader_bam(uuid, bam_path, engine, logger):
    step_dir = os.getcwd()
    bam_name = os.path.basename(bam_path)
    if pipe_util.already_step(step_dir, bam_name + '_reheader', logger):
        logger.info('already completed step `samtools reheader` of %s to %s' % (bam_path, bam_name))
    else:
        logger.info('running step `samtools reheader` of %s to %s' % (bam_path, bam_name))
        home_dir = os.path.expanduser('~')

        #orig header path
        orig_bam_header_path = get_bam_header(bam_path, step_dir, engine, logger)

        #new header path
        reheader_path = os.path.join(step_dir, bam_name + '.reheader')
        cmd = ['head', '-n1', orig_bam_header_path, '>', reheader_path]
        shell_cmd = ' '.join(cmd)
        pipe_util.do_shell_command(shell_cmd, logger)

        #remove @SQ from orig header
        cmd = ["sed", "-i", "'/^@SQ/d'", orig_bam_header_path]
        shell_cmd = ' '.join(cmd)
        pipe_util.do_shell_command(shell_cmd, logger)

        #new @SQ
        python_version = str(sys.version_info.major) + '.' + str(sys.version_info.minor)
        gdc_sq_header_path = os.path.join(home_dir, '.virtualenvs', 'p2_' + uuid, 'GRCh38.d1.vd1.dict')

        #cat new@SQ to orig header
        cmd = ['cat',gdc_sq_header_path, '>>', reheader_path]
        shell_cmd = ' '.join(cmd)
        pipe_util.do_shell_command(shell_cmd, logger)

        #add program info to new header
        cmd = ['tail', '-n', '+2', orig_bam_header_path, '>>', reheader_path]
        shell_cmd = ' '.join(cmd)
        pipe_util.do_shell_command(shell_cmd, logger)

        #reheader BAM
        cmd = [ 'samtools', 'reheader', reheader_path, bam_path, '>', bam_name ]
        shell_cmd = ' '.join(cmd)
        output = pipe_util.do_shell_command(shell_cmd, logger)
        df = time_util.store_time(uuid, shell_cmd, output, logger)
        df['bam'] = bam_name
        unique_key_dict = {'uuid': uuid, 'bam': bam_name}
        table_name = 'time_mem_samtools_reheader'
        df_util.save_df_to_sqlalchemy(df, unique_key_dict, table_name, engine, logger)

        logger.info('completed running step `samtools reheader` of %s to %s' % (bam_path, bam_name))
        pipe_util.create_already_step(step_dir, bam_name + '_reheader', logger)
    return bam_name

def main():
    parser = argparse.ArgumentParser('reheader a BAM to include gdc @SQ info')

    # Logging flags.
    parser.add_argument('-d', '--debug',
        action = 'store_const',
        const = logging.DEBUG,
        dest = 'level',
        help = 'Enable debug logging.',
    )
    parser.set_defaults(level = logging.INFO)


    # Optional db flags
    parser.add_argument('--db_cred_s3url',
                        required = False
    )
    parser.add_argument('--s3cfg_path',
                        required = False
    )


    # Tool flags
    parser.add_argument('-b', '--bam_path',
                        required = True
    )
    parser.add_argument('-c', '--case_id',
                        required = True
    )

    args = parser.parse_args()
    bam_path = args.bam_path
    case_id = args.case_id
    if args.db_cred_s3url:
        db_cred_s3url = args.db_cred_s3url
        s3cfg_path = args.s3cfg_path
    else:
        db_cred_s3url = None

    bam_name = os.path.basename(bam_path)

    logger = pipe_util.setup_logging('readgroup_platform_insertion', args, bam_name)

    if db_cred_s3url is not None: #db server case
        conn_dict = pipe_util.get_connect_dict(db_cred_s3url, s3cfg_path, logger)
        engine = sqlalchemy.create_engine(sqlalchemy.engine.url.URL(**conn_dict))
    else: # local sqlite case
        sqlite_name =  bam_name + '_samtools_reheader.db'
        engine_path = 'sqlite:///' + sqlite_name
        engine = sqlalchemy.create_engine(engine_path, isolation_level='SERIALIZABLE')

    hostname = os.uname()[1]
    logger.info('hostname=%s' % hostname)

    bam_name = reheader_bam(case_id, bam_path, engine, logger)
    
    return


if __name__ == '__main__':
    main()
